/***************************************************************************
 *            read_matrix.h
 *
 *  Mon Jun 28 15:09:13 2010
 *  Copyright  2010  Mariana Penna Lima
 *  <pennalima@gmail.com>
 ****************************************************************************/
/*
 * numcosmo
 * Copyright (C) Mariana Penna Lima 2012 <pennalima@gmail.com>
 * numcosmo is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * numcosmo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _NC_READ_MATRIX_H
#define _NC_READ_MATRIX_H

#include <glib.h>
#include <glib-object.h>

#include <gsl/gsl_matrix.h>

G_BEGIN_DECLS

gsl_matrix * nc_arxive_open (char *filename);  /* le o numero de linhas e colunas do arquivo e aloca memoria. */

G_END_DECLS

#endif /* _NC_READ_MATRIX_H */
